

function main() {
    api.log.info("called main from example 2")
    api.interactive.info("Example 2", "called MAIN from example 2")
}

function save() {
    api.log.info("called save from example 2")
    api.interactive.info("Example 2", "called SAVE from example 2")
}

function open() {
    api.log.info("called open from example 2")
    api.interactive.info("Example 2", "called OPEN from example 2")
}
